---
meta:
    description:
        Deploy security groups in a VPC

    parameters:
        vpc:
            description:
                The physical ID of the target VPC
            value:

        security_groups:
            description:
                A list of security groups
            value:
                []
